==> electric-9.00.jar: com/sun/electric/tool/placement/metrics/AbstractMetricGeneric.java <==
/* -*- tab-width: 4 -*-
 *
 * Electric(tm) VLSI Design System
 *
 * File: AbstractMetricGeneric.java
 * Written by Team 7: Felix Schmidt, Daniel Lechner
 * 
 * This code has been developed at the Karlsruhe Institute of Technology (KIT), Germany, 
 * as part of the course "Multicore Programming in Practice: Tools, Models, and Languages".
 * Contact instructor: Dr. Victor Pankratius (pankratius@ipd.uka.de)
 *
 * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
 *
 * Electric(tm) is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Electric(tm) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Electric(tm); see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, Mass 02111-1307, USA.
 */
package com.sun.electric.tool.placement.metrics;

import java.util.List;

import com.sun.electric.tool.placement.PlacementFrame.PlacementNetwork;
import com.sun.electric.tool.placement.PlacementFrame.PlacementNode;

/**
 * Parallel Placement
 * 
 * General abstract metric class
 */
public abstract class AbstractMetricGeneric<T> {

	protected List<PlacementNode> nodesToPlace;
	protected List<PlacementNetwork> allNetworks;

	/**
	 * 
	 * @param nodesToPlace
	 * @param allNetworks
	 */
	public AbstractMetricGeneric(List<PlacementNode> nodesToPlace, List<PlacementNetwork> allNetworks) {
		this.nodesToPlace = nodesToPlace;
		this.allNetworks = allNetworks;
	}

	/**
	 * compute metric
	 * 
	 * @return metric value
	 */
	public abstract T compute();

	/**
	 * 
	 * @return a metric name
	 */
	public abstract String getMetricName();

	@Override
	public String toString() {
		String output = "Result of " + this.getMetricName() + ": " + this.compute().toString();
		return output;
	}

}

==> electric-9.01.jar: com/sun/electric/tool/placement/metrics/AbstractMetricGeneric.java <==
/* -*- tab-width: 4 -*-
 *
 * Electric(tm) VLSI Design System
 *
 * File: AbstractMetricGeneric.java
 * Written by Team 7: Felix Schmidt, Daniel Lechner
 * 
 * This code has been developed at the Karlsruhe Institute of Technology (KIT), Germany, 
 * as part of the course "Multicore Programming in Practice: Tools, Models, and Languages".
 * Contact instructor: Dr. Victor Pankratius (pankratius@ipd.uka.de)
 *
 * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
 *
 * Electric(tm) is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Electric(tm) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Electric(tm); see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, Mass 02111-1307, USA.
 */
package com.sun.electric.tool.placement.metrics;

import java.util.List;
import java.util.Map;

import com.sun.electric.tool.placement.PlacementAdapter.PlacementConnection;
import com.sun.electric.tool.placement.PlacementFrame.PlacementNetwork;
import com.sun.electric.tool.placement.PlacementFrame.PlacementNode;

/**
 * Parallel Placement
 * 
 * General abstract metric class
 */
public abstract class AbstractMetricGeneric<T> {

	protected List<PlacementNode> nodesToPlace;
	protected List<PlacementNetwork> allNetworks;
	protected Map<PlacementNetwork,List<PlacementConnection>> optimalConnections;

	/**
	 * 
	 * @param nodesToPlace
	 * @param allNetworks
	 * @param optimalConnections
	 */
	public AbstractMetricGeneric(List<PlacementNode> nodesToPlace, List<PlacementNetwork> allNetworks,
		Map<PlacementNetwork,List<PlacementConnection>> optimalConnections) {
		this.nodesToPlace = nodesToPlace;
		this.allNetworks = allNetworks;
		this.optimalConnections = optimalConnections;
	}

	/**
	 * compute metric
	 * 
	 * @return metric value
	 */
	public abstract T compute();

	/**
	 * 
	 * @return a metric name
	 */
	public abstract String getMetricName();

	@Override
	public String toString() {
		String output = "Result of " + this.getMetricName() + ": " + this.compute().toString();
		return output;
	}

}
